<?php
/*
Plugin Name: Simple vCard Theme Settings
Description: Settings for the default GetSimple 3.1 Theme: Simple vCard
Version: 1.0
Author: Chris Cagle
Author URI: http://chriscagle.me/
*/

# get correct id for plugin
$thisfile_simplevc=basename(__FILE__, ".php");
$simplevc_file=GSDATAOTHERPATH .'SimplevCardSettings.xml';

# add in this plugin's language file
i18n_merge($thisfile_simplevc,'en_US');

# register plugin
register_plugin(
	$thisfile_simplevc, 				
	i18n_r($thisfile_simplevc.'/SIMPLEVC_TITLE'),
	'1.0', 
	'Chris Cagle',
	'http://chriscagle.me',
	i18n_r($thisfile_simplevc.'/SIMPLEVC_DESC'),
	'theme', 
	'simplevc_show'
);



# hooks
add_action('theme-sidebar','createSideMenu',array($thisfile_simplevc, i18n_r($thisfile_simplevc.'/SIMPLEVC_TITLE'))); 

# get XML data
if (file_exists($simplevc_file)) {
	$x = getXML($simplevc_file);
	$facebook = $x->facebook;
	$twitter = $x->twitter;
	$linkedin = $x->linkedin;
	$svclocation = $x->location;
	$svcemail = $x->email;
	$jobtitle = $x->jobtitle;
	$photo = $x->photo;
} else {
	$facebook = null;
	$twitter = null;
	$linkedin = null;
	$svclocation = null;
	$svcemail = null;
	$jobtitle = null;
	$photo = null;
}


function simplevc_show() {
	global $simplevc_file, $facebook, $twitter, $linkedin, $jobtitle, $svcemail, $photo, $svclocation, $thisfile_simplevc;
	$success=null;$error=null;

	// submitted form
	if (isset($_POST['submit'])) {
		$facebook=null;	$twitter=null; $linkedin=null; $jobtitle = null; $svclocation = null; $svcemail = null; $photo = null;
		
		# check to see if the URLs provided are valid
		if ($_POST['facebook'] != '') {
			if (validate_url($_POST['facebook'])) {
				$facebook = $_POST['facebook'];
			} else {
				$error .= i18n_r($thisfile_simplevc.'/FACEBOOK_ERROR').' ';
			}
		}
		
		if ($_POST['twitter'] != '') {
			if (validate_url($_POST['twitter'])) {
				$twitter = $_POST['twitter'];
			} else {
				$error .= i18n_r($thisfile_simplevc.'/TWITTER_ERROR').' ';
			}
		}
		
		if ($_POST['linkedin'] != '') {
			if (validate_url($_POST['linkedin'])) {
				$linkedin = $_POST['linkedin'];
			} else {
				$error .= i18n_r($thisfile_simplevc.'/LINKEDIN_ERROR').' ';
			}
		}
		
		if ($_POST['jobtitle'] != '') {
			$jobtitle = $_POST['jobtitle'];
		}
		
		if ($_POST['photo'] != '') {
			$photo = $_POST['photo'];
		}
		
		if ($_POST['svclocation'] != '') {
			$svclocation = $_POST['svclocation'];
		}
		
		if ($_POST['svcemail'] != '') {
			if (check_email_address($_POST['svcemail'])) {
				$svcemail = $_POST['svcemail'];
			} else {
				$error .= i18n_r($thisfile_simplevc.'/EMAIL_ERROR').' ';
			}
		}
		
		# if there are no errors, save data
		if (!$error) {
			$xml = @new SimpleXMLElement('<item></item>');
			$xml->addChild('facebook', $facebook);
			$xml->addChild('twitter', $twitter);
			$xml->addChild('linkedin', $linkedin);
			$xml->addChild('location', $svclocation);
			$xml->addChild('email', $svcemail);
			$xml->addChild('jobtitle', $jobtitle);
			$xml->addChild('photo', $photo);
			
			if (! $xml->asXML($simplevc_file)) {
				$error = i18n_r('CHMOD_ERROR');
			} else {
				$x = getXML($simplevc_file);
				$facebook = $x->facebook;
				$twitter = $x->twitter;
				$linkedin = $x->linkedin;
				$svclocation = $x->location;
				$svcemail = $x->email;
				$jobtitle = $x->jobtitle;
				$photo = $x->photo;
				$success = i18n_r('SETTINGS_UPDATED');
			}
		}
	}

	?>
	<h3><?php i18n($thisfile_simplevc.'/SIMPLEVC_TITLE'); ?></h3>
	
	<?php 
	if($success) { 
		echo '<p style="color:#669933;"><b>'. $success .'</b></p>';
	} 
	if($error) { 
		echo '<p style="color:#cc0000;"><b>'. $error .'</b></p>';
	}
	?>
	
	<form method="post" action="<?php	echo $_SERVER ['REQUEST_URI']?>">
		
		<p><label for="svc_svcemail" ><?php i18n('LABEL_EMAIL'); ?>:</label><input id="svc_svcemail" name="svcemail" class="text" value="<?php echo $svcemail; ?>" type="email" /></p>
		<p><label for="svc_jobtitle" ><?php i18n($thisfile_simplevc.'/JOBTITLE'); ?>:</label><input id="svc_jobtitle" name="jobtitle" class="text" value="<?php echo $jobtitle; ?>" type="text" /></p>
		<p><label for="svc_svclocation" ><?php i18n($thisfile_simplevc.'/LOCATION'); ?>:</label><input id="svc_svclocation" name="svclocation" class="text" value="<?php echo $svclocation; ?>" type="text" /></p>
		<p><label for="svc_photo" ><?php i18n($thisfile_simplevc.'/PHOTO'); ?>:</label><input id="svc_photo" name="photo" class="text" value="<?php echo $photo; ?>" type="url" /><em style="display:block;color:#777;font-size:11px;"><?php i18n($thisfile_simplevc.'/PHOTO_SIZE'); ?></em></p>
		
		<p><label for="svc_facebook" ><?php i18n($thisfile_simplevc.'/FACEBOOK_URL'); ?>:</label><input id="svc_facebook" name="facebook" class="text" value="<?php echo $facebook; ?>" type="url" /></p>
		<p><label for="svc_twitter" ><?php i18n($thisfile_simplevc.'/TWITTER_URL'); ?>:</label><input id="svc_twitter" name="twitter" class="text" value="<?php echo $twitter; ?>" type="url" /></p>
		<p><label for="svc_linkedin" ><?php i18n($thisfile_simplevc.'/LINKEDIN_URL'); ?>:</label><input id="svc_linkedin" name="linkedin" class="text" value="<?php echo $linkedin; ?>" type="url" /></p>
		
		<p><input type="submit" id="submit" class="submit" value="<?php i18n('BTN_SAVESETTINGS'); ?>" name="submit" /></p>
	</form>
	
	<?php

}
